========================
Install Blazar Dashboard
========================

Please see `Blazar Dashboard installation guide (external link) <https://docs.openstack.org/blazar-dashboard/latest/install/index.html>`_.
